@@ -6,7 +6,7 @@ BEGIN {
   $Dist::Zilla::Plugin::Run::Role::Runner::AUTHORITY = 'cpan:GETTY';
 }
 {
-  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.012';
+  $Dist::Zilla::Plugin::Run::Role::Runner::VERSION = '0.014';
 }
 # ABSTRACT: Role for the packages of Dist::Zilla::Plugin::Run
 use Moose::Role;
@@ -87,20 +87,37 @@ sub build_formatter {
     my $dir = $params->{dir} || $self->zilla->built_in;
     $dir = $dir ? "$dir" : '';
 
-    return String::Formatter->new({
-        codes => {
-            # not always available
-            # explicitly pass a string (not an object) [rt-72008]
-            a => defined $params->{archive} ? "$params->{archive}" : '',
-            d => $dir,
-            n => $self->zilla->name,
-            p => $path_separator,
-            v => $self->zilla->version,
-            # positional replace (backward compatible)
-            s => sub { shift(@{ $params->{pos} }) || '' },
-            x => $self->perlpath,
-        },
-    });
+    my $codes = {
+        # not always available
+        # explicitly pass a string (not an object) [rt-72008]
+        a => defined $params->{archive} ? "$params->{archive}" : '',
+
+        # build dir or mint dir
+        d => $dir,
+
+        # dist name
+        n => $self->zilla->name,
+
+        # backward compatibility (don't error)
+        s => '',
+
+        # portability
+        p => $path_separator,
+        x => $self->perlpath,
+    };
+
+    # available during build, not mint
+    unless( $params->{minting} ){
+        $codes->{v} = $self->zilla->version;
+    }
+
+    # positional replace (backward compatible)
+    if( my @pos = @{ $params->{pos} || [] } ){
+        # where are you defined-or // operator?
+        $codes->{s} = sub { my $s = shift(@pos); defined($s) ? $s : '' };
+    }
+
+    return String::Formatter->new({ codes => $codes });
 }
 
 sub current_perl_path {
@@ -118,6 +135,7 @@ sub current_perl_path {
 # vim: set ts=4 sts=4 sw=4 expandtab smarttab:
 
 __END__
+
 =pod
 
 =head1 NAME
@@ -126,11 +144,11 @@ Dist::Zilla::Plugin::Run::Role::Runner - Role for the packages of Dist::Zilla::P
 
 =head1 VERSION
 
-version 0.012
+version 0.014
 
 =head1 DESCRIPTION
 
-This is the base role for all the plugins L<Dist::Zilla::Plugin::Run> delivers. You dont need this.
+This is the base role for all the plugins L<Dist::Zilla::Plugin::Run> delivers. You don't need this.
 
 =head1 AUTHOR
 
@@ -144,4 +162,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
